mlpy.model\_registry package
============================

.. automodule:: mlpy.model_registry
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.model_registry.auto_selector
   mlpy.model_registry.factory
   mlpy.model_registry.registry
